package runner;

import io.github.bonigarcia.wdm.WebDriverManager;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import Utils.JiraTicketCreator;
import Utils.LogParser;
import ai.OpenAISuggestions;
import org.example.SastaTicketPage.SastaTicketPage;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.chrome.ChromeDriver;

import java.io.IOException;
import java.util.List;
import java.util.Map;

public class OneClickRunner {

    private static final Logger log = LogManager.getLogger(OneClickRunner.class);

    public static void main(String[] args) {
        // STEP 1: Run Selenium Script
        WebDriverManager.chromedriver().setup();
        WebDriver driver = new ChromeDriver();
        driver.manage().window().maximize();

        try {
            log.info("Running Selenium script...");

            // Your test steps
            SastaTicketPage page = new SastaTicketPage(driver);
            page.openHomePage();
            page.IClickOnSearchField();
            page.IClickOnSearchFieldDestination();
            page.selectDestinationCity();
            page.clickDate();
            page.clickSearchFlight();

            log.info("Selenium script execution completed.");

        } catch (Exception e) {
            log.error("Selenium execution failed: " + e.getMessage());
        } finally {
            driver.quit();
        }

        // STEP 2: Run Log Parser & AI Suggestion & JIRA Ticket Creation
        String logFilePath = "src/main/resources/log4j3-error.log";
        LogParser logParser = new LogParser();
        List<String> errorLogs = logParser.extractErrors(logFilePath);

        OpenAISuggestions openAI = new OpenAISuggestions();

        for (String errorLog : errorLogs) {
            System.out.println("\n❗ Error Detected: " + errorLog);
            try {
                Map<String, Object> suggestions = openAI.getSuggestions(errorLog);
                String suggestion = suggestions.get("suggestion").toString();

                System.out.println("💡 OpenAI Suggestion: " + suggestion);

                // Create JIRA Ticket
                String summary = "Automation Failure: " + errorLog.split("\\n")[0];
                String description = "Error Log:\n" + errorLog + "\n\nAI Suggestion:\n" + suggestion;

                JiraTicketCreator.createTicket(summary, description);

            } catch (IOException e) {
                e.printStackTrace();
                System.out.println("❌ Failed to get suggestion or create JIRA ticket.");
            }
        }

        System.out.println("\n✅ All steps completed in one run.");
    }
}
